<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>OutputPulseAudioFactory</name>
    <message>
        <location filename="../outputpulseaudiofactory.cpp" line="30"/>
        <source>PulseAudio Plugin</source>
        <translation>PulseAudio 插件</translation>
    </message>
    <message>
        <location filename="../outputpulseaudiofactory.cpp" line="54"/>
        <source>About PulseAudio Output Plugin</source>
        <translation>關於 PulseAudio 匯出插件</translation>
    </message>
    <message>
        <location filename="../outputpulseaudiofactory.cpp" line="55"/>
        <source>Qmmp PulseAudio Output Plugin</source>
        <translation>Qmmp PulseAudio 匯出插件</translation>
    </message>
    <message>
        <location filename="../outputpulseaudiofactory.cpp" line="56"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
